@@ -227,7 +227,7 @@ class HomeMan:
         else:
             d_list = []
             for key in data.keys():
-                d_list += self.__scan_data(data[key])
+                d_list += self.__scan_data(data[key], tag)
             return d_list
 
     def __tidy_data(self):
@@ -677,7 +677,7 @@ def main():
         help='auto sync'
     )
     command_add.add_argument(
-        '-t', '--tags', nargs='*', default=[],
+        '--tags', nargs='*', default=[],
         help='filter node'
     )
 
